Crate kcr_groupsnapshot_storage_k8s_io

Crate kcr_groupsnapshot_storage_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the groupsnapshot.storage.k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

groupsnapshot.storage.k8s.io/v1alpha1

  • VolumeGroupSnapshotClass
  • VolumeGroupSnapshotContent
  • VolumeGroupSnapshot

groupsnapshot.storage.k8s.io/v1beta1

  • VolumeGroupSnapshotClass
  • VolumeGroupSnapshotContent
  • VolumeGroupSnapshot

groupsnapshot.storage.k8s.io/v1beta2

  • VolumeGroupSnapshotClass
  • VolumeGroupSnapshotContent
  • VolumeGroupSnapshot

Modules

v1alpha1
v1beta1
v1beta2