This crate contains kube-rs compatible bindings for Kubernetes custom resources for the groupsnapshot.storage.k8s.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
groupsnapshot.storage.k8s.io/v1alpha1
VolumeGroupSnapshotClassVolumeGroupSnapshotContentVolumeGroupSnapshot
groupsnapshot.storage.k8s.io/v1beta1
VolumeGroupSnapshotClassVolumeGroupSnapshotContentVolumeGroupSnapshot
groupsnapshot.storage.k8s.io/v1beta2
VolumeGroupSnapshotClassVolumeGroupSnapshotContentVolumeGroupSnapshot